//==================================================================================
// The information contained herein is the exclusive property of
// Generalplus Technology Co. And shall not be distributed, reproduced,
// or disclosed in whole in part without prior written permission.
//       (C) COPYRIGHT 2009   Generalplus TECHNOLOGY CO.                            
//                   ALL RIGHTS RESERVED
// The entire notice above must be reproduced on all authorized copies.
//==================================================================================
//==================================================================================
// Name                  : SPI0_Driver.inc
// Applied Body          : GPL951
// Programmer            : 
// Description           : SPI0 driver header file
// History version       : 
// Rev #      Date         Who			Comments
// -----	 -----------   ---------	--------------------------------------------
// 1.0	     2016/04/14   JackyLin		Oringinal Version
// 1.1		 2017/04/12   JackyLin		1. _SPI0_WriteNByte function bug fix.
//										2. Add slave mode transmission function code and MasterMode/SlaveMode define
//==================================================================================

//==========================================
// Include file area
//==========================================


//==========================================
// Constant define area
//==========================================
   

//==========================================
// External declare area
//==========================================
.external R_SPI0_ReadOneByteData
.external R_SPI0_TXDataPoint
.external R_SPI0_RXDataPoint
.external R_SPI0_DataLength
.external R_SPI0_Mode

.external R_Slave_SPI0_ReadOneByteData
// ======================================================================================
// Function name: SPI0_Intial
// Purpose		: SPI0 interface initial 
// Parameter	: r1: SPI_CLK_SEL. SPI clcok is system clock divided by 2/4/8/16/32/64/128 
//				  Here, SPI_CLK_SEL=0 is system clock/2. SPI_CLK_SEL=1 is system clock/4. ... SPI_CLK_SEL=7 is system clock/128.  
// Return		: None
// Destroy		: r1,r2 
// ======================================================================================
.external	F_SPI0_Intial

// ======================================================================================
// Function name: F_SPI0_CSHigh
// Purpose		: SPI0 chip selection set to high 
// Parameter	: None 
// Return		: None
// Destroy		: r1 
// ======================================================================================
.external	F_SPI0_CSHigh


// ======================================================================================
// Function name: F_SPI0_CSLow
// Purpose		: SPI0 chip selection set to low 
// Parameter	: None 
// Return		: None
// Destroy		: r1 
// ======================================================================================
.external	F_SPI0_CSLow


// ======================================================================================
// Function name: F_SPI0_Close
// Purpose		: SPI0 function Disable.  
// Parameter	: None 
// Return		: None
// Destroy		: r1 
// ======================================================================================
.external	F_SPI0_Close


// ======================================================================================
// Function name: F_SPI0_WriteOneByte
// Purpose		: SPI transmit one byte data 
// Parameter	: r1: transmit data 
// Return		: r1=0: complete
//				  r1=-1: Timeout
//				  read back data will put in R_SPI_ReadOneByteData variable 		
// Destroy		: r1,r2 
// ======================================================================================
.external	F_SPI0_WriteOneByte


// ======================================================================================
// Function name: SPI0_WriteNByte
// Purpose		: SPI N byte write(from buffer) 
// Parameter	: r4: transmit data point low
//				  r3: transmit data point high	 
//				  r5: transmit data length  
// Return		: r1=0: complete
//				  r1=-1: Timeout
// Destroy		: r1,r2,r3,r4,r5 
// ======================================================================================
.external	F_SPI0_WriteNByte


// ======================================================================================
// Function name: SPI0_ReadNByte
// Purpose		: SPI N byte write(from buffer) 
// Parameter	: r4: store receive data point low
//				  r3: store receive data point high	
//				  r5: receive data length 
// Return		: r1=0: complete
//				  r1=-1: Timeout
// Destroy		: r1,r2,r3,r4,r5 
// ======================================================================================	
.external	F_SPI0_ReadNByte


// ======================================================================================
// Function name: SPI0_TransmissionDMA
// Purpose		: SPI0 transmission by DMA. 
// Parameter	: int* R_SPI0_TXDataPoint: transmit data buffer Address. 
//				  int* R_SPI0_RXDataPoint: receive data buffer Address.
//				  int R_SPI0_DataLength: transmission data length
//				  int Mode: transmission mode. here, Mode=0,transmit address is constant and transmit address is byte mode, receive address is constant and recevie address is byte mode.   
//				    		  						 Mode=1,transmit address is increase and transmit address is byte mode, receive address is constant and recevie address is byte mode.	
//				    		  						 Mode=2,transmit address is constant and transmit address is word mode, receive address is constant and recevie address is byte mode.	
//				    		  						 Mode=3,transmit address is increase and transmit address is word mode, receive address is constant and recevie address is byte mode.	
//				    		  						 Mode=4,transmit address is constant and transmit address is byte mode, receive address is increase and recevie address is byte mode.	
//				    		  						 Mode=5,transmit address is increase and transmit address is byte mode, receive address is increase and recevie address is byte mode.	
//				    		  						 Mode=6,transmit address is constant and transmit address is word mode, receive address is increase and recevie address is byte mode.	
//				    		  						 Mode=7,transmit address is increase and transmit address is word mode, receive address is increase and recevie address is byte mode.	
//				    		  						 Mode=8,transmit address is constant and transmit address is byte mode, receive address is constant and recevie address is word mode.	
//				    		  						 Mode=9,transmit address is increase and transmit address is byte mode, receive address is constant and recevie address is word mode.	
//				    		  						 Mode=10,transmit address is constant and transmit address is word mode, receive address is constant and recevie address is word mode.	
//				    		  						 Mode=11,transmit address is increase and transmit address is word mode, receive address is constant and recevie address is word mode.	
//				    		  						 Mode=12,transmit address is constant and transmit address is byte mode, receive address is constant and recevie address is word mode.	
//				    		  						 Mode=13,transmit address is increase and transmit address is byte mode, receive address is constant and recevie address is word mode.	
//				    		  						 Mode=14,transmit address is constant and transmit address is word mode, receive address is constant and recevie address is word mode.	
//				    		  						 Mode=15,transmit address is increase and transmit address is word mode, receive address is constant and recevie address is word mode.	
// Return		: r1=0: complete
//				  r1=-1: Timeout
// Destroy		: r1,r2 
// ======================================================================================
.external	F_SPI0_TransmissionDMA



// ======================================================================================
// Function name: Slave_SPI0_Intial
// Purpose		: SPI0 interface slave mode initial 
// Parameter	: None  
// Return		: None
// Destroy		: r1
// ======================================================================================
.external F_Slave_SPI0_Intial


// ======================================================================================
// Function name: Slave_SPI0_WriteOneByte
// Purpose		: SPI slave mode transmit and receive one byte data.               
// Parameter	: int TransmitData: transmit data 
// Return		: None.
//				  After this function call. User need call Slave_SPI0_Status to polling is master read data out?  
//                If Slave_SPI0_Status return 0, the read data will be put in Slave_SPI0_ReadOneByteData
// Destroy		: r1,r2 
// ======================================================================================	
.external F_Slave_SPI0_WriteOneByte


// ======================================================================================
// Function name: Slave_SPI0_WriteNByte
// Purpose		: slave mode SPI N byte write(from buffer). here, the read data will be give up. 
// Parameter	: int* R_Slave_SPI0_TXDataPoint: TX data buffer Address, 
//				  int DataLength: transmit data length  
// Return		: None
//				  After this function call. User need call Slave_SPI0_Status to polling is master read data out?
//                If Slave_SPI0_Status return 0. Means transmit data is finish. 
// Destroy		: r1,r2,r3,r4,r5  
// ======================================================================================	
.external F_Slave_SPI0_WriteNByte


// ======================================================================================
// Function name: Slave_SPI0_ReadNByte
// Purpose		: Slave mode SPI N byte Read(to buffer). Here, SPI will send zero data out.  
// Parameter	: int* R_SPI0_RXDataPoint: receive data buffer Address.
//				  int R_SPI0_DataLength: receive data length 
// Return		: None
//				  After this function call. User need call Slave_SPI0_Status to polling is master send data out?  
//                If Slave_SPI0_Status return 0. Means receive data is finish.
// Destroy		: r1,r2,r3,r4,r5 
// ======================================================================================	
.external F_Slave_SPI0_ReadNByte


// ======================================================================================
// Function name: Slave_SPI0_ISRService
// Purpose		: SPI0 slave mode interrupt service code. Put this function to SPI0 RX interrupt service routine   
// Parameter	: None 
// Return		: None
// Destroy		: r1,r2,r3,r4
// ======================================================================================
.external F_Slave_SPI0_ISRService


// ======================================================================================
// Function name: Slave_SPI0_Status
// Purpose		: Slave mode data tramssion status check. After slave mode data transmit/receive function called. user need call this function to check is master had to teansmit/receive data.   
// Parameter	: None 
// Return		: remain data length.
//				  if return 0, means data transsiom is finish.
//				  if return 0xFFFF, means SPI slave receive over run. There are data mission.		
// Destroy		: r1
// ======================================================================================
.external F_Slave_SPI0_Status